<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
  "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>{% block title %}{% endblock %}</title>
  <link rel="stylesheet" href="/assets/css/reset.css" type="text/css" charset="utf-8"/>
</head>
<body>
{% block content %}{% endblock %}
</body>
</html>